@@ -75,7 +75,8 @@ class AMQPData(GeneralData):
                     arguments={'x-message-ttl' : self.ttl})
                 self.channel.queue_bind(self.queue_name, self.exchange, self.routing_key)
             else:
-                self.queue_name = self.channel.queue_declare("",exclusive=True)
+                self.queue_default = self.channel.queue_declare("",exclusive=True)
+                self.queue_name =  self.queue_default.method.name
                 rprint("Queue name from SOURCE", self.queue_name)
                 self.channel.queue_bind(self.queue_name, exchange=self.exchange)
         except Exception as e:
